@@ -204,12 +204,18 @@ def check_filter(response, comp = 0, filter_number = 0):
 
 
 
+#check if a button component has a specific label and link
+def check_button(response, comp = 0):
+    
+    return response.json()[0]['attachment']['body'][comp]['details']['label'], response.json()[0]['attachment']['body'][comp]['details']['link']
+
+
 
 ## run the query test
 
 def run_test(query = '',
              n_cards = None, check_component_types = None, 
-             check_table_columns = None, check_filters_existance = None, 
+             check_table_columns = None, check_filters_existance = None, check_button_existace = None,
            
             print_response = False):
     
@@ -279,6 +285,17 @@ def run_test(query = '',
                 
             print('Check for filters passed')
             
+        
+        if check_button_existace:
+            
+            for position, button in enumerate(check_button_existace):
+                
+                if button != []:
+                
+                    assert list(check_button(response, position)) == button
+            
+            print('Check for button passed')
+            
             
         message_body += "<br><b style='color:green;'>Test Successful</b> for query: {}".format(query)
         
